==> haskell-criterion-1.1.4.0-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.4.0
id: criterion-1.1.4.0-4biPmvVVxM2IwWf7Swko0o
key: criterion-1.1.4.0-4biPmvVVxM2IwWf7Swko0o
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: f65f86eda18fb0ec00b331568297d14a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.4.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.1.4.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/criterion-1.1.4.0
hs-libraries: HScriterion-1.1.4.0-4biPmvVVxM2IwWf7Swko0o
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.1.2.0-KSzOWeOw6cI7ymVovOXtxy
    ansi-wl-pprint-0.6.7.3-1EvdXA5apxHECzKM1XGqTG base-4.9.0.0
    binary-0.8.3.0 bytestring-0.10.8.1
    cassava-0.4.5.1-LEMf6YfZGWIHz5MwqBRNZd
    code-page-0.1.3-4Xob7qJDA6VAZKPymJS77x containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0
    hastache-0.6.1-INBEYETTDYrFnEdQooIIgl
    js-flot-0.8.3-DwW7tRfA2DS2odTaEQO7re
    js-jquery-3.2.1-JUma5JJqcuZ7fbys9QVYyu
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.6.0-FkwmwAh2ZNWGdUe7qkQMIm
    optparse-applicative-0.13.2.0-2f8ecj6rdMuFtm9J78ebBE
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    statistics-0.13.3.0-3odQbqBOMQX6SdSeB3Xpg6
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-algorithms-0.7.0.1-5uWiEsia2ll7iojszUQtFk
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.2.0.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.2.0.0
id: criterion-1.2.0.0-ESaXc4j2fci1MZ4Px5lTtR
key: criterion-1.2.0.0-ESaXc4j2fci1MZ4Px5lTtR
license: BSD3
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
abi: 6a264b6a8fc24f4e0c07df17f9caf117
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.2.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/criterion-1.2.0.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/criterion-1.2.0.0
hs-libraries: HScriterion-1.2.0.0-ESaXc4j2fci1MZ4Px5lTtR
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH
    ansi-wl-pprint-0.6.7.3-6GCcsFDbx2V8PibFjHfpG5 base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF binary-0.8.3.0
    bytestring-0.10.8.1 cassava-0.4.5.1-6nAtGHRM63O1ZwdTsoDhV8
    code-page-0.1.3-4Xob7qJDA6VAZKPymJS77x containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN filepath-1.4.1.0
    js-flot-0.8.3-DwW7tRfA2DS2odTaEQO7re
    js-jquery-3.2.1-JUma5JJqcuZ7fbys9QVYyu
    microstache-1-3o5WLA6mgs38napCvvbBnZ
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.6.0-FkwmwAh2ZNWGdUe7qkQMIm
    optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    statistics-0.14.0.2-4L5puLRk1cUCzXygdqegab
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-algorithms-0.7.0.1-5uWiEsia2ll7iojszUQtFk
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
